@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use vars qw($VERSION);
 
-$VERSION = '0.02';
+$VERSION = '0.04';
 
 use Acme::CPANAuthors::Register (
   AAR => q[Alessandro Ranellucci],
@@ -26,10 +26,12 @@ use Acme::CPANAuthors::Register (
   CWEST => q[Casey West],
   DAGOLDEN => q[David Golden],
   DAMS => q[Damien Krotkine],
+  DAVINCHI => q[Pavel Boldin],
   DAZJORZ => q[Sjors Gielen],
   DGL => q[David Leadbeater],
   DMAKI => q[Daisuke Maki],
   DMCC => q[Dan McCormick],
+  DOLMEN => q[Olivier 'dolmen' Mengue],
   DSNOPEK => q[David Snopek],
   ECALDER => q[Erick Calder],
   EWATERS => q[Eric Waters],
@@ -71,7 +73,6 @@ use Acme::CPANAuthors::Register (
   MRPERSON => q[Curtis Hawthorne],
   MSERGEANT => q[MSERGEANT],
   NPEREZ => q[Nicholas Perez],
-  NRG => q[Odintsov Pavel],
   NUFFIN => q[Yuval Kogman],
   PAULV => q[Paul Visscher],
   PGUZIS => q[Peter Guzis],
@@ -93,14 +94,15 @@ use Acme::CPANAuthors::Register (
   SUZUKI => q[Yuji Suzuki],
   TAG => q[Scott McCoy],
   TBR => q[Thiago Berlitz Rondon],
+  TOKUHIROM => q[Tokuhiro Matsuno],
   TONYC => q[Tony Cook],
   TYPESTER => q[Daisuke Murase],
   ULTRADM => q[George Nistorica],
   VANY => q[Ivan B. Serezhkin],
   WANG => q[wb@95700.net],
   WHOPPIX => q[Jonathan Ringstad],
-  WOREMACX => q[Wore Macx],
   XANTUS => q[David Davis],
+  XSAWYERX => q[Sawyer X],
   YAPPO => q[Kazuhiro Osawa],
   YBLUSSEAU => q[Yves Blusseau],
   ZOFFIX => q[Zoffix Znet],
@@ -154,10 +156,12 @@ It is currently statically generated information, I hope to make it dynamic in t
   CWEST => q[Casey West],
   DAGOLDEN => q[David Golden],
   DAMS => q[Damien Krotkine],
+  DAVINCHI => q[Pavel Boldin],
   DAZJORZ => q[Sjors Gielen],
   DGL => q[David Leadbeater],
   DMAKI => q[Daisuke Maki],
   DMCC => q[Dan McCormick],
+  DOLMEN => q[Olivier 'dolmen' Mengue],
   DSNOPEK => q[David Snopek],
   ECALDER => q[Erick Calder],
   EWATERS => q[Eric Waters],
@@ -199,7 +203,6 @@ It is currently statically generated information, I hope to make it dynamic in t
   MRPERSON => q[Curtis Hawthorne],
   MSERGEANT => q[MSERGEANT],
   NPEREZ => q[Nicholas Perez],
-  NRG => q[Odintsov Pavel],
   NUFFIN => q[Yuval Kogman],
   PAULV => q[Paul Visscher],
   PGUZIS => q[Peter Guzis],
@@ -221,14 +224,15 @@ It is currently statically generated information, I hope to make it dynamic in t
   SUZUKI => q[Yuji Suzuki],
   TAG => q[Scott McCoy],
   TBR => q[Thiago Berlitz Rondon],
+  TOKUHIROM => q[Tokuhiro Matsuno],
   TONYC => q[Tony Cook],
   TYPESTER => q[Daisuke Murase],
   ULTRADM => q[George Nistorica],
   VANY => q[Ivan B. Serezhkin],
   WANG => q[wb@95700.net],
   WHOPPIX => q[Jonathan Ringstad],
-  WOREMACX => q[Wore Macx],
   XANTUS => q[David Davis],
+  XSAWYERX => q[Sawyer X],
   YAPPO => q[Kazuhiro Osawa],
   YBLUSSEAU => q[Yves Blusseau],
   ZOFFIX => q[Zoffix Znet],
